==> apache-ignite-3.0.0-src.zip: apache-ignite-3.0.0-src/modules/network/src/main/java/org/apache/ignite/internal/network/configuration/ClusterMembershipConfigurationSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.network.configuration;

import org.apache.ignite.configuration.annotation.Config;
import org.apache.ignite.configuration.annotation.ConfigValue;
import org.apache.ignite.configuration.annotation.Value;

/**
 * Cluster membership configuration.
 */
@Config
public class ClusterMembershipConfigurationSchema {
    /** Periodic membership data sync interval. */
    @Value(hasDefault = true)
    public final int membershipSyncInterval = 30_000;

    /** Failure detector ping interval. */
    @Value(hasDefault = true)
    public final int failurePingInterval = 1_000;

    /** ScaleCube-specific configuration. */
    @ConfigValue
    public ScaleCubeConfigurationSchema scaleCube;
}

==> apache-ignite-3.1.0-src.zip: apache-ignite-3.1.0-src/modules/network/src/main/java/org/apache/ignite/internal/network/configuration/ClusterMembershipConfigurationSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.network.configuration;

import org.apache.ignite.configuration.annotation.Config;
import org.apache.ignite.configuration.annotation.ConfigValue;
import org.apache.ignite.configuration.annotation.PublicName;
import org.apache.ignite.configuration.annotation.Value;

/**
 * Cluster membership configuration.
 */
@Config
public class ClusterMembershipConfigurationSchema {
    /** Periodic membership data sync interval. */
    @Value(hasDefault = true)
    @PublicName(legacyNames = "membershipSyncInterval")
    public final int membershipSyncIntervalMillis = 30_000;

    /** Failure detector ping interval. */
    @Value(hasDefault = true)
    @PublicName(legacyNames = "failurePingInterval")
    public final int failurePingIntervalMillis = 2_000;

    /** ScaleCube-specific configuration. */
    @ConfigValue
    public ScaleCubeConfigurationSchema scaleCube;
}
